import React, { useContext, useEffect, useMemo, useState } from 'react';
import {Row, Table} from "react-bootstrap";

import { Organisation } from "../Schema";
import { createOrganisationDataLookup, getYearsAndNrens, loadDataWithFilterSelectionFallback } from "../helpers/dataconversion";
import DataPage from '../components/DataPage';
import Filter from "../components/graphing/Filter"
import {ExportType, Sections} from '../helpers/constants';
import DownloadDataButton from "../components/DownloadDataButton";
import { FilterSelectionContext } from '../helpers/FilterSelectionProvider';
import DownloadImageChartButton from "../components/DownloadImageChartButton";
import ChartContainer from "../components/graphing/ChartContainer";


function getJSXFromMap(data: Map<string, Map<number, Organisation[]>>) {
    return Array.from(data.entries()).map(([nren, nrenMap]) => {
        return Array.from(nrenMap.entries()).map(([year, organization], yearIndex) => (
            <tr key={nren + year} className='dotted-border'>
                <td className='pt-3 nren-column text-nowrap'>{yearIndex == 0 && nren}</td>
                <td className='pt-3 year-column'>{year}</td>
                <td className='pt-3 blue-column'>{organization[0].name}</td>
            </tr>
        ))
    })
}
function ParentOrganisation() {
    const [organisationData, setOrganisationData] = useState<Organisation[]>([]);
    const {filterSelection, setFilterSelection } = useContext(FilterSelectionContext);

    const { years, nrens } = useMemo(
        () => getYearsAndNrens(organisationData),
        [organisationData]
    );

    const selectedData = (organisationData).filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );
    const organisationDataset = createOrganisationDataLookup(selectedData);

    useEffect(() => {
        loadDataWithFilterSelectionFallback('/api/organization/parent', setOrganisationData, setFilterSelection);
    }, [setFilterSelection]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        max1year
    />

    return (
        <DataPage title="NREN Parent Organisations" 
        description='The table shows the NRENs parent organisation. You can select only one year at a time
        and multiple NRENs. This table can be used to compare the parent organisation of NRENs.'
        category={Sections.Organisation} filter={filterNode}>
            <>
                <Row>
                    <DownloadDataButton data={organisationData} filename="nren_parent_organisations.csv" exportType={ExportType.CSV}/>
                    <DownloadDataButton data={organisationData} filename="nren_parent_organisations.xlsx" exportType={ExportType.EXCEL}/>
                </Row>
                <DownloadImageChartButton filename='nren_parent_organisations'/>
                <ChartContainer>
                    <Table borderless className='compendium-table'>
                        <thead>
                        <tr>
                            <th className='nren-column'>NREN</th>
                            <th className='year-column'>Year</th>
                            <th className='blue-column'>Parent Organisation</th>
                        </tr>
                        </thead>
                        <tbody>
                        {getJSXFromMap(organisationDataset)}
                        </tbody>
                    </Table>
                </ChartContainer>
            </>
        </DataPage>

    );
}
export default ParentOrganisation;
