import React, { createContext, useState, useEffect } from 'react';

interface Props {
    children: React.ReactNode;
}

interface User {
    name: string,
    email?: string,
    permissions: {
        admin: boolean,
        active: boolean,
    }
}

async function fetchUser(): Promise<User> {
    const response = await fetch('/api/user');
    const user = await response.json();
    return user
}

const anonymousUser: User = { 'name': '', email: '', permissions: { admin: false, active: false } };

const userContext = createContext<{
    user: User;
    logout: () => void;
}>({
    user: anonymousUser,
    logout: () => { }
});


const UserProvider: React.FC<Props> = ({ children }) => {
    const [user, setUser] = useState<User>(anonymousUser);

    async function logoutUser() {
        await fetch('/logout');
        setUser(anonymousUser);
    }

    useEffect(() => {
        fetchUser().then(user => {
            setUser(user)
        });
    }, []);

    return (
        <userContext.Provider value={{ user, logout: logoutUser }}>
            {children}
        </userContext.Provider>
    );
};

export { userContext };
export default UserProvider;