import logging
from typing import Any

from flask import Blueprint, jsonify

from compendium_v2.routes import common
from compendium_v2.db.auth_model import NREN
from sqlalchemy import select

from compendium_v2.db import db

routes = Blueprint('nren', __name__)
logger = logging.getLogger(__name__)

NREN_RESPONSE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'nren': {
            'type': 'object',
            'properties': {
                'id': {'type': 'integer'},
                'name': {'type': 'string'},
                'country': {'type': 'string'},
            },
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/nren'}
}


@routes.route('/list', methods=['GET'])
@common.require_accepts_json
def all_nrens_view() -> Any:
    def _extract_nren_data(entry: NREN):
        return {
            'id': entry.id,
            'name': entry.name,
            'country': entry.country
        }

    nren_entries = [_extract_nren_data(nren) for nren in db.session.scalars(select(NREN))]
    return jsonify(nren_entries)
