import logging
from typing import List, Optional

from sqlalchemy.orm import Mapped, mapped_column, relationship
from sqlalchemy.schema import ForeignKey

from compendium_v2.db import db


logger = logging.getLogger(__name__)

SURVEY_DB_BIND = 'survey'

# Unfortunately flask-sqlalchemy doesnt fully support DeclarativeBase yet.
# See https://github.com/pallets-eco/flask-sqlalchemy/issues/1140
# mypy: disable-error-code="name-defined"


class Budgets(db.Model):
    __bind_key__ = SURVEY_DB_BIND
    __tablename__ = 'budgets'
    id: Mapped[int] = mapped_column(primary_key=True)
    budget: Mapped[Optional[str]]
    year: Mapped[Optional[int]]
    country_code: Mapped[Optional[str]] = mapped_column(ForeignKey('nrens.country_code'))
    nren: Mapped[Optional['Nrens']] = relationship(back_populates='budgets')


class Nrens(db.Model):
    __bind_key__ = SURVEY_DB_BIND
    __tablename__ = 'nrens'
    id: Mapped[int] = mapped_column(primary_key=True)
    abbreviation: Mapped[Optional[str]]
    country_code: Mapped[Optional[str]]
    budgets: Mapped[List['Budgets']] = relationship(back_populates='nren')
