import React, { ReactElement, useContext } from "react";
import { useNavigate, Link } from "react-router-dom";
import { Container, Row } from "react-bootstrap";
import { userContext } from "./providers/UserProvider";

function Landing(): ReactElement {
    const { user } = useContext(userContext);
    const navigate = useNavigate();

    const loggedIn = !!user.id;
    const hasNren = loggedIn ? !!user.nrens.length : false;
    const activeNren = hasNren ? user.nrens[0] : '';
    const isAdmin = loggedIn ? user.permissions.admin : false;

    const moveToSurvey = () => {
        const currentYear = new Date().getFullYear();
        navigate(`/survey/response/${currentYear}/${activeNren}`);
        return <></>
    }

    return (
        <Container className="py-5 grey-container">
            <Row>
                <div className="center-text">
                    <h1 className="geant-header">THE GÉANT COMPENDIUM OF NRENS SURVEY</h1>


                    <div className="wordwrap pt-4" style={{ maxWidth: '75rem' }}>
                        <p style={{ textAlign: "left" }}>
                            Hello,
                            <br />Welcome to the GÉANT Compendium Survey. NREN Compendium administrators can login via Single Sign On (SSO) <a href="/login">here</a>, which will complete their registration to fill in the 2023 Compendium survey.
                            This will send a notification to the Compendium administration team and they will assign you to your NREN.
                            <br />Once this step has been completed, you will receive an email from the administration team. We aim to get back to you the same working day, but sometimes may take a little longer.
                            <br />If you are not sure whether you are a Compendium Administrator for your NREN, please contact your GÉANT Partner Relations relationship manager.
                            <br />Thank you.
                        </p>

                        <span>Current registration status:</span>
                        <br />
                        <br />
                        {isAdmin ? <ul>
                            <li><span>You are logged in as a Compendium Administrator</span></li>
                            <li><span>Click <Link to="/survey/admin/surveys">here</Link> to access the survey management page.</span></li>
                            <li><span>Click <Link to="/survey/admin/users">here</Link> to access the user management page.</span></li>
                        </ul> : <ul>
                            {!isAdmin && hasNren && moveToSurvey()}
                            {loggedIn ? <li><span>You are logged in</span></li> : <li><span>You are not logged in</span></li>}
                            {loggedIn && !hasNren && <li><span>Your access to the survey has not been approved</span></li>}
                            {loggedIn && !hasNren && <li><span>Once you have been approved, you will immediately be directed to the relevant survey upon visiting this page</span></li>}
                        </ul>}


                    </div>


                </div>
            </Row>
        </Container >
    );
}

export default Landing;
